<?php
/**
 * Meta Box Options
 *
 * Meta Box Options for pages
 *
 * Please do not edit this file. This file is part of the CyberChimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category CyberChimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) {
	exit;
}

if( is_admin() ) {

	/*********************************** PAGE OPTIONS STARTS ******************************************/
	$ifeature_cc_image_path    = get_template_directory_uri() . '/cyberchimps/lib/images/';
	$ifeature_cc_themenamefull = apply_filters( 'ifeature_cc_current_theme_name', 'CyberChimps' );
	$ifeature_cc_pagedocs      = apply_filters( 'ifeature_cc_page_options_help', 'http://cyberchimps.com/guide/how-to-use-the-page-or-post-page-element/' );

	$ifeature_cc_fields = array( array(
		'type'    => 'image_select',
		'id'      => 'ifeature_cc_page_sidebar',
		'class'   => '',
		'name'    => __( 'Select Page Layout', 'ifeature' ),
		'options' => apply_filters( 'ifeature_cc_sidebar_layout_options', array(
			'full_width'    => $ifeature_cc_image_path . '1col.png',
			'right_sidebar' => $ifeature_cc_image_path . '2cr.png'
		) ),
		'std'     => 'right_sidebar'
	),
		array(
			'type'  => 'checkbox',
			'id'    => 'ifeature_cc_page_title_toggle',
			'class' => 'checkbox',
			'name'  => __( 'Page Title', 'ifeature' ),
			'std'   => 1
		),
		array(
			'type'    => 'section_order',
			'id'      => 'ifeature_cc_page_section_order',
			'class'   => '',
			'name'    => __( 'Page Elements', 'ifeature' ),
			'options' => apply_filters( 'ifeature_cc_elements_draganddrop_page_options', array(
				'boxes'              => __( 'Boxes', 'ifeature' ),
				'page_section'       => __( 'Page', 'ifeature' ),
				'portfolio_lite'     => __( 'Portfolio Lite', 'ifeature' ),
				'slider_lite'        => __( 'Slider Lite', 'ifeature' ),
				'featured_lite'      => __( 'Featured lite', 'ifeature' ),
				'twitterbar_section' => __( 'Twitter Bar', 'ifeature' )
			) ),
			'std'     => array( 'page_section' )
		),
		array(
			'type'      => 'help',
			'id'        => 'ifeature_cc_page_help',
			'class'     => 'help-message',
			'name'      => __( 'Need Help?', 'ifeature' ),
			'help_text' => '<a href="' . $ifeature_cc_pagedocs . '" target="_blank">' . sprintf( __( 'Visit the %s page options guide', 'ifeature' ), $ifeature_cc_themenamefull ) . '</a></td>'
		),
	);
	/*
	 * configure your meta box
	 */
	$ifeature_cc_config = array(
		'id'             => 'ifeature_cc_page_options', // meta box id, unique per meta box
		'title'          => __( 'Page Options', 'ifeature' ), // meta box title
		'pages'          => array( 'page' ), // post types, accept custom post types as well, default is array('post'); optional
		'context'        => 'normal', // where the meta box appear: normal (default), advanced, side; optional
		'priority'       => 'high', // order of meta box: high (default), low; optional
		'fields'         => apply_filters( 'ifeature_cc_page_metabox_options',$ifeature_cc_fields), // list of meta fields (can be added by field arrays)
		'local_images'   => false, // Use local or hosted images (meta box images for add/remove)
		'use_with_theme' => true //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
	);

	/*
	 * Initiate your meta box
	 */
	$ifeature_cc_meta = new Ifeature_Meta_Box( $ifeature_cc_config );
	/************************************ PAGE OPTIONS ENDS ***************************************/

	/************************************ POST SLIDER OPTIONS STARTS ***************************************/
	$ifeature_cc_slider_fields = array(
		array(
			'type'  => 'single_image',
			'id'    => 'ifeature_cc_slider_image',
			'class' => '',
			'name'  => __( 'Slider Image', 'ifeature' ),
			'std'   => '',
		),
		array(
			'type'  => 'text',
			'id'    => 'ifeature_cc_slider_caption',
			'class' => '',
			'name'  => __( 'Slider Caption', 'ifeature' )
		),
		array(
			'type'  => 'text',
			'id'    => 'ifeature_cc_slider_url',
			'class' => '',
			'name'  => __( 'Custom Slide Link', 'ifeature' )
		),
		array(
			'type'  => 'checkbox',
			'id'    => 'ifeature_cc_slider_hidetitle',
			'class' => 'checkbox',
			'name'  => __( 'Title', 'ifeature' ),
			'std'   => 1
		),
		array(
			'type'  => 'checkbox',
			'id'    => 'ifeature_cc_slider_hidecaption',
			'class' => 'checkbox',
			'name'  => __( 'Caption', 'ifeature' ),
			'std'   => 0
		)
	);

	/*
	* configure your meta box
	*/
	$ifeature_cc_slider_config = array(
		'id'             => 'post_slider_options', // meta box id, unique per meta box
		'title'          => __( 'Custom Feature Slides', 'ifeature' ), // meta box title
		'pages'          => array( 'post' ), // post types, accept custom post types as well, default is array('post'); optional
		'context'        => 'normal', // where the meta box appear: normal (default), advanced, side; optional
		'priority'       => 'high', // order of meta box: high (default), low; optional
		'fields'         => $ifeature_cc_slider_fields, // list of meta fields (can be added by field arrays)
		'local_images'   => false, // Use local or hosted images (meta box images for add/remove)
		'use_with_theme' => true //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
	);

	/*
	* Initiate your meta box
	*/
	if( 'free' != ifeature_cc_theme_check() ) {
		$ifeature_cc_slider_meta = new Ifeature_Meta_Box( $ifeature_cc_slider_config );
	}
	/************************************ POST SLIDER OPTIONS ENDS ***************************************/
}
