<?php
/**
 * Title: Options customizer
 *
 * Description: Defines option fields for theme customizer.
 *
 * Please do not edit this file. This file is part of the Cyber Chimps Framework and all modifications
 * should be made in a child theme.
 *
 * @category Cyber Chimps Framework
 * @package  Framework
 * @since    1.0
 * @author   CyberChimps
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v3.0 (or later)
 * @link     http://www.cyberchimps.com/
 */

add_action( 'customize_register', 'ifeature_cc_customize' );
function ifeature_cc_customize( $wp_customize ) {

	/**
	 * Class Ifeature_Form
	 *
	 * Creates a form input type with the option to add description and placeholders
	 */
	require_once get_parent_theme_file_path( 'cyberchimps/options/control-checkbox-multiple.php' );

	class Ifeature_Form extends WP_Customize_Control {

		public function render_content() {
			switch ( $this->type ) {
				case 'textarea':
					?>
					<label>
						<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
						<textarea value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); ?> style="width: 97%; height: 200px;"></textarea>
					</label>
					<?php
					break;
			}
		}
	}

	class Ifeature_Typography_Size extends WP_Customize_Control {
		public $type = 'select';

		public function render_content() {
			?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<select <?php $this->link(); ?>>
					<?php
					foreach ( $this->choices as $value => $label ) {
						echo '<option value="' . esc_attr( $label ) . 'px"' . selected( $this->value(), $value, false ) . '>' . esc_attr( $label ) . 'px</option>';
					}
					?>
				</select>
			</label>
			<?php
		}
	}

	/********** Class for background image option starts *************/
	class Ifeature_Background_Image extends WP_Customize_Control {
		public $type = 'radio';

		public function render_content() {
			?>
			<style>
				.images-radio-subcontainer img {
					margin-top: 5px;
					padding: 2px;
					border: 5px solid #eee;
				}

				.images-radio-subcontainer img.of-radio-img-selected {
					border: 5px solid #5DA7F2;
				}

				.images-radio-subcontainer img:hover {
					cursor: pointer;
					border: 5px solid #5DA7F2;
				}
				#accordion-section-ifeature_cc_header_section .customize-control-image img{ width: auto;}
				#accordion-section-ifeature_cc_social_media .images-skin-subcontainer img{ height: auto;}
			</style>
			<script>
				jQuery(function ($) {
					$('.of-radio-img-img').click(function () {
						$(this).parent().parent().parent().find('.of-radio-img-img').removeClass('of-radio-img-selected');
						$(this).addClass('of-radio-img-selected');
					});
				});
			</script>

			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<em>
				<small><?php esc_html_e( 'make sure you have removed the image above before selecting one of these', 'ifeature' ); ?></small>
			</em>
			<?php
			foreach ( $this->choices as $value => $label ) :

				// if get theme mod background image has a value then we need to set cyberchimps bg to none
				$test_bg  = $this->value();
				$test_bg  = ( get_theme_mod( 'background_image' ) ) ? 'none' : $test_bg;
				$name     = '_customize-radio-' . $this->id;
				$selected = ( $test_bg == $value ) ? 'of-radio-img-selected' : '';
				?>
				<div class="images-radio-subcontainer">
					<label>
						<input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>"
															  <?php
																$this->link();
																checked( $test_bg, $value );
																?>
						 style="display:none;"/>
						<img src="<?php echo esc_html( $label ); ?>" class="of-radio-img-img <?php echo esc_attr( $selected ); ?>"/><br/>
					</label>
				</div>
				<?php
			endforeach;
		}
	}

	/********** Class for background image option ends *************/

	/********** Class for skin color selection option starts *************/
	class Ifeature_skin_selector extends WP_Customize_Control {
		public $type = 'radio';

		public function render_content() {
			?>
			<style>
				.images-skin-subcontainer, .images-radio-subcontainer {
					display: inline-block;
				}

				#customize-control-ifeature_cc_background em {
					display: block;
				}

				.images-skin-subcontainer img {
					margin-top: 5px;
					padding: 2px;
					border: 5px solid #eee;
					height: 80px;
					width: 80px;
				}

				.images-skin-subcontainer img.of-radio-img-selected {
					border: 5px solid #5DA7F2;
				}

				.images-skin-subcontainer img:hover {
					cursor: pointer;
					border: 5px solid #5DA7F2;
				}
				#accordion-section-ifeature_cc_header_section .customize-control-image img{ width: auto;}
				#accordion-section-ifeature_cc_social_media .images-skin-subcontainer img{ height: auto;}
			</style>
			<script>
				jQuery(function ($) {
					$('.of-radio-img-img').click(function () {
						$(this).parent().parent().parent().find('.of-radio-img-img').removeClass('of-radio-img-selected');
						$(this).addClass('of-radio-img-selected');
					});

					// Script to show hide the Google Text Font input depending on the value of the Text select
					var font = $('#customize-control-typography_face select').val();
					if (font != 'Google Fonts') {
						$('#customize-control-google_font_field').hide();
					}
					else {
						$('#customize-control-google_font_field').show();
					}
					$('#customize-control-typography_face select').change(function () {
						var font_change = $(this).val();
						if (font_change != 'Google Fonts') {
							$('#customize-control-google_font_field').hide();
						}
						else {
							$('#customize-control-google_font_field').show();
						}
					});

					// Script to hide show the Google Heading Font input depending on value of the Heading select
					var text = $('#customize-control-font_family_headings select').val();
					if (text != 'Google Fonts') {
						$('#customize-control-google_font_headings').hide();
					}
					else {
						$('#customize-control-google_font_headings').show();
					}
					$('#customize-control-font_family_headings select').change(function () {
						var text_change = $(this).val();
						if (text_change != 'Google Fonts') {
							$('#customize-control-google_font_headings').hide();
						}
						else {
							$('#customize-control-google_font_headings').show();
						}
					});

				});
			</script>

			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<?php
			foreach ( $this->choices as $value => $label ) :

				// if get theme mod background image has a value then we need to set cyberchimps bg to none
				$test_skin = $this->value();
				$name      = '_customize-radio-' . $this->id;
				$selected  = ( $test_skin == $value ) ? 'of-radio-img-selected' : '';
				?>
				<div class="images-skin-subcontainer">
					<label>
						<input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>"
															  <?php
																$this->link();
																checked( $test_skin, $value );
																?>
						 style="display:none;"/>
						<img src="<?php echo esc_html( $label ); ?>" class="of-radio-img-img <?php echo esc_attr( $selected ); ?>"/>
					</label>
				</div>
				<?php
			endforeach;
		}
	}
	/*     * ******** Class for skin color selection option ends ************ */
	$imagepath             = get_template_directory_uri() . '/cyberchimps/lib/images/';
	$args                  = array(
		'type'         => 'post',
		'orderby'      => 'name',
		'order'        => 'ASC',
		'hide_empty'   => 1,
		'hierarchical' => 1,
		'taxonomy'     => 'category',
	);
	$option_categories     = array();
	$category_lists        = get_categories( $args );
	$option_categories[''] = esc_html( __( 'Choose Category', 'ifeature' ) );
	foreach ( $category_lists as $category ) {
		$option_categories[ $category->term_id ] = $category->name;
	}

	$option_all_post_cat = array();
	foreach ( $category_lists as $category ) {
		$option_all_post_cat[ $category->term_id ] = $category->name;
	}

	/*
	 --------------------------------------------------------------
	  // MAIN HEADER SECTION
	  -------------------------------------------------------------- */
	$wp_customize->add_panel(
		'header_id',
		array(
			'priority'       => 46,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Header', 'ifeature' ),
			'description'    => __( 'Several settings for Header', 'ifeature' ),
		)
	);

	$wp_customize->add_section(
		'ifeature_cc_header_section',
		array(
			'priority'       => 10,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Header Option', 'ifeature' ),
			'panel'          => 'header_id',
		)
	);

	// custom logo url
	$wp_customize->add_setting(
		'ifeature_cc_options[custom_logo_url]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'custom_logo_url',
		array(
			'label'    => __( 'Custom Logo URL', 'ifeature' ),
			'section'  => 'ifeature_cc_header_section',
			'settings' => 'ifeature_cc_options[custom_logo_url]',
			'type'     => 'checkbox',
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[custom_logo_url_link]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		'custom_logo_url_link',
		array(
			'label'    => __( 'Enter Custom Logo URL', 'ifeature' ),
			'section'  => 'ifeature_cc_header_section',
			'settings' => 'ifeature_cc_options[custom_logo_url_link]',
			'type'     => 'text',
		)
	);

	// Disable logo
	$wp_customize->add_setting(
		'ifeature_cc_options[custom_logo]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'custom_logo',
		array(
			'label'    => __( 'Display Logo?', 'ifeature' ),
			'section'  => 'ifeature_cc_header_section',
			'settings' => 'ifeature_cc_options[custom_logo]',
			'type'     => 'checkbox',
		)
	);

	// Add Logo image
	$wp_customize->add_setting(
		'ifeature_cc_options[custom_logo_uploader]',
		array(
			'default'           => apply_filters( 'ifeature_cc_default_logo', $imagepath . '/achimps.png' ),
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_upload',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'custom_logo_uploader',
			array(
				'label'    => __( 'Upload Logo Image', 'ifeature' ),
				'section'  => 'ifeature_cc_header_section',
				'settings' => 'ifeature_cc_options[custom_logo_uploader]',
				'type'     => 'image',
			)
		)
	);

	// Disable search bar.
	$wp_customize->add_setting(
		'ifeature_cc_options[searchbar]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'searchbar',
		array(
			'label'    => __( 'Display Searchbar?', 'ifeature' ),
			'section'  => 'ifeature_cc_header_section',
			'settings' => 'ifeature_cc_options[searchbar]',
			'type'     => 'checkbox',
		)
	);

	/*
	 --------------------------------------------------------------
	  // SOCIAL MEDIA SECTION
	  -------------------------------------------------------------- */
	$wp_customize->add_section(
		'ifeature_cc_social_media',
		array(
			'priority'       => 15,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Social Option', 'ifeature' ),
			'panel'          => 'header_id',
		)
	);

	// Select social Icon Style
	$social_choices = apply_filters(
		'ifeature_cc_social_icon_options',
		array(
			'default' => $imagepath . 'social/thumbs/icons-default.png',
			'legacy'  => $imagepath . 'social/thumbs/icons-classic.png',
			'round'   => $imagepath . 'social/thumbs/icons-round.png',
		)
	);
	if ( count( $social_choices ) > 1 ) {
		$wp_customize->add_setting(
			'ifeature_cc_options[theme_backgrounds]',
			array(
				'default'           => apply_filters( 'ifeature_cc_social_icon_default', 'default' ),
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);

		$wp_customize->add_control(
			new Ifeature_skin_selector(
				$wp_customize,
				'theme_backgrounds',
				array(
					'label'    => __( 'Choose your icon style', 'ifeature' ),
					'section'  => 'ifeature_cc_social_media',
					'settings' => 'ifeature_cc_options[theme_backgrounds]',
					'choices'  => $social_choices,
				)
			)
		);
	}
	// Add Facebook Setting

	$wp_customize->add_setting(
		'ifeature_cc_options[social_facebook]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_facebook',
			array(
				'label'    => __( 'Display Facebook?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_facebook]',
				'type'     => 'checkbox',
			)
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[facebook_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'facebook_url',
			array(
				'label'    => __( 'Facebook URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[facebook_url]',
			)
		)
	);

	// Add Twitter Setting

	$wp_customize->add_setting(
		'ifeature_cc_options[social_twitter]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_twitter',
			array(
				'label'    => __( 'Display Twitter?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_twitter]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[twitter_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'twitter_url',
			array(
				'label'    => __( 'Twitter URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[twitter_url]',
			)
		)
	);

	// Add Google+ Setting
	$wp_customize->add_setting(
		'ifeature_cc_options[social_google]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_google',
			array(
				'label'    => __( 'Display Google?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_google]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[google_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'google_url',
			array(
				'label'    => __( 'Google+ URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[google_url]',
			)
		)
	);

	// Add LinkedIn Setting
	$wp_customize->add_setting(
		'ifeature_cc_options[social_linkedin]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_linkedin',
			array(
				'label'    => __( 'Display LinkedIn?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_linkedin]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[linkedin_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'linkedin_url',
			array(
				'label'    => __( 'LinkedIn URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[linkedin_url]',
			)
		)
	);

	// Add Youtube Setting
	$wp_customize->add_setting(
		'ifeature_cc_options[social_youtube]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_youtube',
			array(
				'label'    => __( 'Display Youtube?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_youtube]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[youtube_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'youtube_url',
			array(
				'label'    => __( 'Youtube URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[youtube_url]',
			)
		)
	);

	// Add Flickr Setting
	$wp_customize->add_setting(
		'ifeature_cc_options[social_flickr]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_flickr',
			array(
				'label'    => __( 'Display Flickr?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_flickr]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[flickr_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'flickr_url',
			array(
				'label'    => __( 'Flickr URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[flickr_url]',
			)
		)
	);

	// Add Pinterest Setting.
	$wp_customize->add_setting(
		'ifeature_cc_options[social_pinterest]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_pinterest',
			array(
				'label'    => __( 'Display Pinterest?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_pinterest]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[pinterest_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'pinterest_url',
			array(
				'label'    => __( 'Pinterest URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[pinterest_url]',
			)
		)
	);

	// Add GoogleMap Setting
	$wp_customize->add_setting(
		'ifeature_cc_options[social_googlemaps]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_googlemaps',
			array(
				'label'    => __( 'Display Google Maps?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_googlemaps]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[googlemaps_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'googlemaps_url',
			array(
				'label'    => __( 'Google Maps URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[googlemaps_url]',
			)
		)
	);

	// Add Email Setting.
	$wp_customize->add_setting(
		'ifeature_cc_options[social_email]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_email',
			array(
				'label'    => __( 'Display Email?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_email]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[email_url]',
		array(
			'sanitize_callback' => 'sanitize_email',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'email_url',
			array(
				'label'    => __( 'Email Address', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[email_url]',
			)
		)
	);

	// Add RSS Setting
	$wp_customize->add_setting(
		'ifeature_cc_options[social_rss]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_rss',
			array(
				'label'    => __( 'Display RSS?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_rss]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[rss_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'rss_url',
			array(
				'label'    => __( 'RSS URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[rss_url]',
			)
		)
	);

	// Add Instagram Setting
	$wp_customize->add_setting(
		'ifeature_cc_options[social_instagram]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_instagram',
			array(
				'label'    => __( 'Display Instagram?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_instagram]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[instagram_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'instagram_url',
			array(
				'label'    => __( 'Instagram URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[instagram_url]',
			)
		)
	);

	// Add Vimeo Setting.

	$wp_customize->add_setting(
		'ifeature_cc_options[social_vimeo]',
		array(
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			'type'              => 'option',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'social_vimeo',
			array(
				'label'    => __( 'Display Vimeo?', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[social_vimeo]',
				'type'     => 'checkbox',
			)
		)
	);
	$wp_customize->add_setting(
		'ifeature_cc_options[vimeo_url]',
		array(
			'sanitize_callback' => 'esc_url_raw',
			'type'              => 'option',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'vimeo_url',
			array(
				'label'    => __( 'Vimeo URL', 'ifeature' ),
				'section'  => 'ifeature_cc_social_media',
				'settings' => 'ifeature_cc_options[vimeo_url]',
			)
		)
	);

	// Add contact section

	$wp_customize->add_section(
		'ifeature_cc_contact_section',
		array(
			'priority'       => 16,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Contact Elements', 'ifeature' ),
			'panel'          => 'header_id',
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[contact_details]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_textarea',
		)
	);
	$wp_customize->add_control(
		'contact_details',
		array(
			'label'    => __( 'Contact Number', 'ifeature' ),
			'section'  => 'ifeature_cc_contact_section',
			'settings' => 'ifeature_cc_options[contact_details]',
			'type'     => 'textarea',
		)
	);

	/*
	 --------------------------------------------------------------
	  // BLOG SECTION
	  -------------------------------------------------------------- */
	$wp_customize->add_panel(
		'blog_id',
		array(
			'priority'       => 56,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Blog', 'ifeature' ),
			'description'    => __( 'Several settings for Blog', 'ifeature' ),
		)
	);

	$wp_customize->add_section(
		'ifeature_cc_blog_section',
		array(
			'priority'       => 10,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Blog Option', 'ifeature' ),
			'description'    => __( 'Blog elements configuration', 'ifeature' ),
			'panel'          => 'blog_id',
		)
	);

	$sidebar_choices = apply_filters(
		'ifeature_cc_blog_layout_options',
		array(
			'full_width'    => $imagepath . '1col.png',
			'right_sidebar' => $imagepath . '2cr.png',
		)
	);
	if ( count( $sidebar_choices ) > 1 ) {
		$wp_customize->add_setting(
			'ifeature_cc_options[sidebar_images]',
			array(
				'default'           => 'right_sidebar',
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);

		$wp_customize->add_control(
			new Ifeature_skin_selector(
				$wp_customize,
				'sidebar_images',
				array(
					'label'    => __( 'Select Page Layout', 'ifeature' ),
					'section'  => 'ifeature_cc_blog_section',
					'settings' => 'ifeature_cc_options[sidebar_images]',
					'choices'  => $sidebar_choices,
				)
			)
		);
	}

	$wp_customize->add_setting(
		'ifeature_cc_options[blog_title]',
		array(
			'default'           => 0,
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);

	$wp_customize->add_control(
		'blog_title',
		array(
			'label'    => __( 'Blog Title', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[blog_title]',
			'class'    => 'blog_title_toggle',
			'type'     => 'checkbox',
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[blog_title_text]',
		array(
			'default'           => __( 'Blog', 'ifeature' ),
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		'blog_title_text',
		array(
			'label'    => __( 'Blog Title Text', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[blog_title_text]',
			'type'     => 'text',
		)
	);

	// Disable Post Format Icons
	$wp_customize->add_setting(
		'ifeature_cc_options[post_format_icons]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'post_format_icons',
		array(
			'label'    => __( 'Post Format Icons', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[post_format_icons]',
			'type'     => 'checkbox',
		)
	);

	// Post Excerpts
	$wp_customize->add_setting(
		'ifeature_cc_options[post_excerpts]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'post_excerpts',
		array(
			'label'    => __( 'Post Excerpts', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[post_excerpts]',
			'type'     => 'checkbox',
		)
	);

	// Post Excerpts Read More Text
	$wp_customize->add_setting(
		'ifeature_cc_options[blog_read_more_text]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);
	$wp_customize->add_control(
		'blog_read_more_text',
		array(
			'label'    => __( 'Read More Text', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[blog_read_more_text]',
			'type'     => 'text',
		)
	);

	// Post Excerpts Length
	$wp_customize->add_setting(
		'ifeature_cc_options[blog_excerpt_length]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);
	$wp_customize->add_control(
		'blog_excerpt_length',
		array(
			'label'    => __( 'Excerpt Length', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[blog_excerpt_length]',
			'type'     => 'text',
		)
	);

	// Disable Featured Images
	$wp_customize->add_setting(
		'ifeature_cc_options[post_featured_images]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'post_featured_images',
		array(
			'label'    => __( 'Featured Images', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[post_featured_images]',
			'type'     => 'checkbox',
		)
	);

	// Disable Post Byline Author
	$wp_customize->add_setting(
		'ifeature_cc_options[post_byline_author]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'post_byline_author',
		array(
			'label'    => __( 'Post Byline Author', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[post_byline_author]',
			'type'     => 'checkbox',
		)
	);

	// Disable Post Byline Categories
	$wp_customize->add_setting(
		'ifeature_cc_options[post_byline_categories]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'post_byline_categories',
		array(
			'label'    => __( 'Post Byline Categories', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[post_byline_categories]',
			'type'     => 'checkbox',
		)
	);

	// Post Byline Date
	$wp_customize->add_setting(
		'ifeature_cc_options[post_byline_date]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'post_byline_date',
		array(
			'label'    => __( 'Post Byline Date', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[post_byline_date]',
			'type'     => 'checkbox',
		)
	);

	// Post Byline Comments
	$wp_customize->add_setting(
		'ifeature_cc_options[post_byline_comments]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'post_byline_comments',
		array(
			'label'    => __( 'Post Byline Comments', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[post_byline_comments]',
			'type'     => 'checkbox',
		)
	);

	// Post Byline Tags
	$wp_customize->add_setting(
		'ifeature_cc_options[post_byline_tags]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'post_byline_tags',
		array(
			'label'    => __( 'Post Byline Tags', 'ifeature' ),
			'section'  => 'ifeature_cc_blog_section',
			'settings' => 'ifeature_cc_options[post_byline_tags]',
			'type'     => 'checkbox',
		)
	);

	$wp_customize->add_setting( 'ifeature_cc_exclude_post_cat', array( 'sanitize_callback' => 'ifeature_cc_sanitize_multiple_checkboxes' ) );
	$wp_customize->add_control(
		new ifeature_cc_Customize_Control_Checkbox_Multiple(
			$wp_customize,
			'ifeature_cc_exclude_post_cat',
			array(
				'section'     => 'ifeature_cc_blog_section',
				'label'       => __( 'Exclude Categories from Blog page', 'ifeature' ),
				'description' => __( 'Please choose the post categories that should not be displayed on the blog page', 'ifeature' ),
				'settings'    => 'ifeature_cc_exclude_post_cat',
				'choices'     => $option_all_post_cat,
			)
		)
	);
	/*
	 --------------------------------------------------------------
	  // BLOG SLIDER SECTION
	  -------------------------------------------------------------- */
	// theme check
	$theme_check = ifeature_cc_theme_check();
	if ( $theme_check == 'free' ) {
		$wp_customize->add_section(
			'ifeature_cc_blogslider_section',
			array(
				'priority'       => 15,
				'capability'     => 'edit_theme_options',
				'theme_supports' => '',
				'title'          => __( 'Blog Slider Lite', 'ifeature' ),
				'description'    => sprintf( __( 'Slider Lite limits you to a total of 3 images throughout your whole site. Upgrade to %1$s to be able to create more images. Categorize them and display each category on a different page.', 'ifeature' ), '<a href="' . apply_filters( 'ifeature_cc_upgrade_link', esc_url_raw( 'http://cyberchimps.com' ) ) . '" title="' . apply_filters( 'ifeature_cc_upgrade_pro_title', __( 'Pro', 'ifeature' ) ) . '">' . apply_filters( 'ifeature_cc_upgrade_pro_title', __( 'Pro', 'ifeature' ) ) . '</a>' ),
				'panel'          => 'blog_id',
			)
		);
		// Slider image 1
		$wp_customize->add_setting(
			'ifeature_cc_options[image_one_slide]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'image_one_slide',
				array(
					'label'    => __( 'Upload Slider Image 1', 'ifeature' ),
					'section'  => 'ifeature_cc_blogslider_section',
					'settings' => 'ifeature_cc_options[image_one_slide]',
					'type'     => 'image',
				)
			)
		);

		// Slider image 1 url
		$wp_customize->add_setting(
			'ifeature_cc_options[image_one_slide_url]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'image_one_slide_url',
			array(
				'label'    => __( 'Slide 1 URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogslider_section',
				'settings' => 'ifeature_cc_options[image_one_slide_url]',
				'type'     => 'text',
			)
		);

		// Slider image 2.
		$wp_customize->add_setting(
			'ifeature_cc_options[image_two_slide]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'image_two_slide',
				array(
					'label'    => __( 'Upload Slider Image 2', 'ifeature' ),
					'section'  => 'ifeature_cc_blogslider_section',
					'settings' => 'ifeature_cc_options[image_two_slide]',
					'type'     => 'image',
				)
			)
		);

		// Slider image 2 url.
		$wp_customize->add_setting(
			'ifeature_cc_options[image_two_slide_url]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'image_two_slide_url',
			array(
				'label'    => __( 'Slide 2 URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogslider_section',
				'settings' => 'ifeature_cc_options[image_two_slide_url]',
				'type'     => 'text',
			)
		);

		// Slider image 3.
		$wp_customize->add_setting(
			'ifeature_cc_options[image_three_slide]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'image_three_slide',
				array(
					'label'    => __( 'Upload Slider Image 3', 'ifeature' ),
					'section'  => 'ifeature_cc_blogslider_section',
					'settings' => 'ifeature_cc_options[image_three_slide]',
					'type'     => 'image',
				)
			)
		);

		// Slider image 3 url.
		$wp_customize->add_setting(
			'ifeature_cc_options[image_three_slide_url]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'image_three_slide_url',
			array(
				'label'    => __( 'Slide 3 URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogslider_section',
				'settings' => 'ifeature_cc_options[image_three_slide_url]',
				'type'     => 'text',
			)
		);

		/*
		 --------------------------------------------------------------
		  // BLOG PORTFOLIO SECTION
		  -------------------------------------------------------------- */

		$wp_customize->add_section(
			'ifeature_cc_blogportfolio_section',
			array(
				'priority'       => 15,
				'capability'     => 'edit_theme_options',
				'theme_supports' => '',
				'title'          => __( 'Portfolio Lite', 'ifeature' ),
				'description'    => sprintf( __( 'Portfolio Lite limits you to a total of 4 items throughout your whole site. Upgrade to %1$s to be able to create as many portfolio items as you like. Categorize them and display each category on a different page.', 'ifeature' ), '<a href="' . apply_filters( 'ifeature_cc_upgrade_link', esc_url_raw( 'http://cyberchimps.com' ) ) . '" title="' . apply_filters( 'ifeature_cc_upgrade_pro_title', __( 'Pro', 'ifeature' ) ) . '">' . apply_filters( 'ifeature_cc_upgrade_pro_title', __( 'Pro', 'ifeature' ) ) . '</a>' ),
				'panel'          => 'blog_id',
			)
		);

		// Portfolio image 1
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_one]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'ifeature_cc_blog_portfolio_lite_image_one',
				array(
					'label'    => __( 'First Portfolio Image', 'ifeature' ),
					'section'  => 'ifeature_cc_blogportfolio_section',
					'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_one]',
					'type'     => 'image',
				)
			)
		);

		// Portfolio caption 1
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_one_caption]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_lite_image_one_caption',
			array(
				'label'    => __( 'First Portfolio Image Caption', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'default'  => apply_filters( 'ifeature_cc_portfolio_lite_caption1', 'CyberChimps' ),
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_one_caption]',
				'type'     => 'text',
			)
		);

		// Portfolio link checkbox 1
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_link_toggle_one]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_link_toggle_one',
			array(
				'label'    => __( 'Show First Porfolio Link', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_link_toggle_one]',
				'type'     => 'checkbox',
			)
		);

		// Portfolio link 1
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_link_url_one]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_link_url_one',
			array(
				'label'    => __( 'First Porfolio URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_link_url_one]',
				'type'     => 'text',
			)
		);

		// Portfolio image 2
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_two]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'ifeature_cc_blog_portfolio_lite_image_two',
				array(
					'label'    => __( 'Second Portfolio Image', 'ifeature' ),
					'section'  => 'ifeature_cc_blogportfolio_section',
					'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_two]',
					'type'     => 'image',
				)
			)
		);

		// Portfolio caption 2
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_two_caption]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_lite_image_two_caption',
			array(
				'label'    => __( 'Second Portfolio Image Caption', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'default'  => apply_filters( 'ifeature_cc_portfolio_lite_caption2', 'CyberChimps' ),
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_two_caption]',
				'type'     => 'text',
			)
		);

		// Portfolio link checkbox 2
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_link_toggle_two]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_link_toggle_two',
			array(
				'label'    => __( 'Show Second Porfolio Link', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_link_toggle_two]',
				'type'     => 'checkbox',
			)
		);

		// Portfolio link 2
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_link_url_two]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_link_url_two',
			array(
				'label'    => __( 'Second Porfolio URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_link_url_two]',
				'type'     => 'text',
			)
		);

		// Portfolio image 3
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_three]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'ifeature_cc_blog_portfolio_lite_image_three',
				array(
					'label'    => __( 'Third Portfolio Image', 'ifeature' ),
					'section'  => 'ifeature_cc_blogportfolio_section',
					'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_three]',
					'type'     => 'image',
				)
			)
		);

		// Portfolio caption 3
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_three_caption]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_lite_image_three_caption',
			array(
				'label'    => __( 'Third Portfolio Image Caption', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'defualt'  => apply_filters( 'ifeature_cc_portfolio_lite_caption3', 'CyberChimps' ),
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_three_caption]',
				'type'     => 'text',
			)
		);

		// Portfolio link checkbox 3
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_link_toggle_three]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_link_toggle_three',
			array(
				'label'    => __( 'Show Third Porfolio Link', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_link_toggle_three]',
				'type'     => 'checkbox',
			)
		);

		// Portfolio link 3
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_link_url_three]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_link_url_three',
			array(
				'label'    => __( 'Third Porfolio URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_link_url_three]',
				'type'     => 'text',
			)
		);

		// Portfolio image 4.
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_four]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'ifeature_cc_blog_portfolio_lite_image_four',
				array(
					'label'    => __( 'Forth Portfolio Image', 'ifeature' ),
					'section'  => 'ifeature_cc_blogportfolio_section',
					'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_four]',
					'type'     => 'image',
				)
			)
		);

		// Portfolio caption 4.
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_four_caption]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_lite_image_four_caption',
			array(
				'label'    => __( 'Forth Portfolio Image Caption', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'defualt'  => apply_filters( 'ifeature_cc_portfolio_lite_caption4', 'CyberChimps' ),
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_lite_image_four_caption]',
				'type'     => 'text',
			)
		);

		// Portfolio link checkbox 4.
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_link_toggle_four]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_link_toggle_four',
			array(
				'label'    => __( 'Show Forth Porfolio Link', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_link_toggle_four]',
				'type'     => 'checkbox',
			)
		);

		// Portfolio link 4
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_portfolio_link_url_four]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_portfolio_link_url_four',
			array(
				'label'    => __( 'Forth Porfolio URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogportfolio_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_portfolio_link_url_four]',
				'type'     => 'text',
			)
		);

		/*
		 --------------------------------------------------------------
		  // BOXES LITE SECTION
		  -------------------------------------------------------------- */
		$wp_customize->add_section(
			'ifeature_cc_blogboxes_section',
			array(
				'priority'       => 15,
				'capability'     => 'edit_theme_options',
				'theme_supports' => '',
				'title'          => __( 'Boxes Lite', 'ifeature' ),
				'description'    => sprintf( __( 'Boxes Lite limits you to a total of 3 boxes throughout your whole site. Upgrade to %1$s to be able to create as many boxes as you like. Categorize them and display each category on a different page.', 'ifeature' ), '<a href="' . apply_filters( 'ifeature_cc_upgrade_link', esc_url_raw( 'http://cyberchimps.com' ) ) . '" title="' . apply_filters( 'ifeature_cc_upgrade_pro_title', __( 'Pro', 'ifeature' ) ) . '">' . apply_filters( 'ifeature_cc_upgrade_pro_title', __( 'Pro', 'ifeature' ) ) . '</a>' ),
				'panel'          => 'blog_id',
			)
		);

		// Boxes image 1
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_one]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'ifeature_cc_blog_boxes_lite_image_one',
				array(
					'label'    => __( 'First Box Image', 'ifeature' ),
					'section'  => 'ifeature_cc_blogboxes_section',
					'settings' => 'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_one]',
					'type'     => 'image',
				)
			)
		);

		// URL of Box link 1
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_boxes_link_url_one]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_boxes_link_url_one',
			array(
				'label'    => __( 'First Link URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogboxes_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_boxes_link_url_one]',
				'type'     => 'text',
			)
		);

		// Box text 1
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_one_text]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_textarea',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_boxes_lite_image_one_text',
			array(
				'label'    => __( 'First Box Text', 'ifeature' ),
				'section'  => 'ifeature_cc_blogboxes_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_one_text]',
				'type'     => 'textarea',
			)
		);

		// Boxes image 2
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_two]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'ifeature_cc_blog_boxes_lite_image_two',
				array(
					'label'    => __( 'Second Box Image', 'ifeature' ),
					'section'  => 'ifeature_cc_blogboxes_section',
					'settings' => 'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_two]',
					'type'     => 'image',
				)
			)
		);

		// URL of Box link 2
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_boxes_link_url_two]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_boxes_link_url_two',
			array(
				'label'    => __( 'Second Link URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogboxes_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_boxes_link_url_two]',
				'type'     => 'text',
			)
		);

		// Box text 2
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_two_text]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_textarea',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_boxes_lite_image_two_text',
			array(
				'label'    => __( 'Second Box Text', 'ifeature' ),
				'section'  => 'ifeature_cc_blogboxes_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_two_text]',
				'type'     => 'textarea',
			)
		);

		// Boxes image 3
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_three]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_upload',
			)
		);
		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'ifeature_cc_blog_boxes_lite_image_three',
				array(
					'label'    => __( 'Third Box Image', 'ifeature' ),
					'section'  => 'ifeature_cc_blogboxes_section',
					'settings' => 'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_three]',
					'type'     => 'image',
				)
			)
		);

		// URL of Box link 3
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_boxes_link_url_three]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_boxes_link_url_three',
			array(
				'label'    => __( 'Third Link URL', 'ifeature' ),
				'section'  => 'ifeature_cc_blogboxes_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_boxes_link_url_three]',
				'type'     => 'text',
			)
		);

		// Box text 3
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_three_text]',
			array(
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_textarea',
			)
		);
		$wp_customize->add_control(
			'ifeature_cc_blog_boxes_lite_image_three_text',
			array(
				'label'    => __( 'Third Box Text', 'ifeature' ),
				'section'  => 'ifeature_cc_blogboxes_section',
				'settings' => 'ifeature_cc_options[ifeature_cc_blog_boxes_lite_image_three_text]',
				'type'     => 'textarea',
			)
		);
	}

	/*
	 --------------------------------------------------------------
	  // TEMPLATE SECTION
	  -------------------------------------------------------------- */
	$wp_customize->add_panel(
		'template_id',
		array(
			'priority'       => 58,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Template', 'ifeature' ),
			'description'    => __( 'Several settings for Template', 'ifeature' ),
		)
	);

	/*     * ******* Start Single Post Options ********** */
	$wp_customize->add_section(
		'ifeature_cc_template_section',
		array(
			'priority'       => 10,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Single Post', 'ifeature' ),
			'panel'          => 'template_id',
		)
	);

	if ( count( $sidebar_choices ) > 1 ) {
		$wp_customize->add_setting(
			'ifeature_cc_options[single_post_sidebar_options]',
			array(
				'default'           => 'right_sidebar',
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);

		$wp_customize->add_control(
			new Ifeature_skin_selector(
				$wp_customize,
				'single_post_sidebar_options',
				array(
					'label'    => __( 'Sidebar Options', 'ifeature' ),
					'section'  => 'ifeature_cc_template_section',
					'settings' => 'ifeature_cc_options[single_post_sidebar_options]',
					'choices'  => $sidebar_choices,
				)
			)
		);
	}

	// Disable Post Authot bio
	$wp_customize->add_setting(
		'ifeature_cc_options[single_post_author_bio]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'single_post_author_bio',
		array(
			'label'    => __( 'Post Author Bio', 'ifeature' ),
			'section'  => 'ifeature_cc_template_section',
			'settings' => 'ifeature_cc_options[single_post_author_bio]',
			'type'     => 'checkbox',
		)
	);

	// Disable Post Title
	$wp_customize->add_setting(
		'ifeature_cc_options[single_post_title]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'single_post_title',
		array(
			'label'    => __( 'Post Title', 'ifeature' ),
			'section'  => 'ifeature_cc_template_section',
			'settings' => 'ifeature_cc_options[single_post_title]',
			'type'     => 'checkbox',
		)
	);

	// Disable Featured Images
	$wp_customize->add_setting(
		'ifeature_cc_options[single_post_featured_images]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'single_post_featured_images',
		array(
			'label'    => __( 'Featured Images', 'ifeature' ),
			'section'  => 'ifeature_cc_template_section',
			'settings' => 'ifeature_cc_options[single_post_featured_images]',
			'type'     => 'checkbox',
		)
	);

	// Disable Post Format Icons
	$wp_customize->add_setting(
		'ifeature_cc_options[single_post_format_icons]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'single_post_format_icons',
		array(
			'label'    => __( 'Post Format Icons', 'ifeature' ),
			'section'  => 'ifeature_cc_template_section',
			'settings' => 'ifeature_cc_options[single_post_format_icons]',
			'type'     => 'checkbox',
		)
	);

	// Disable Post Byline Author
	$wp_customize->add_setting(
		'ifeature_cc_options[single_post_byline_author]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'single_post_byline_author',
		array(
			'label'    => __( 'Post Byline Author', 'ifeature' ),
			'section'  => 'ifeature_cc_template_section',
			'settings' => 'ifeature_cc_options[single_post_byline_author]',
			'type'     => 'checkbox',
		)
	);

	// Disable Post Byline Categories
	$wp_customize->add_setting(
		'ifeature_cc_options[single_post_byline_categories]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'single_post_byline_categories',
		array(
			'label'    => __( 'Post Byline Categories', 'ifeature' ),
			'section'  => 'ifeature_cc_template_section',
			'settings' => 'ifeature_cc_options[single_post_byline_categories]',
			'type'     => 'checkbox',
		)
	);

	// Post Byline Date
	$wp_customize->add_setting(
		'ifeature_cc_options[single_post_byline_date]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'single_post_byline_date',
		array(
			'label'    => __( 'Post Byline Date', 'ifeature' ),
			'section'  => 'ifeature_cc_template_section',
			'settings' => 'ifeature_cc_options[single_post_byline_date]',
			'type'     => 'checkbox',
		)
	);

	// Post Byline Comments
	$wp_customize->add_setting(
		'ifeature_cc_options[single_post_byline_comments]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'single_post_byline_comments',
		array(
			'label'    => __( 'Post Byline Comments', 'ifeature' ),
			'section'  => 'ifeature_cc_template_section',
			'settings' => 'ifeature_cc_options[single_post_byline_comments]',
			'type'     => 'checkbox',
		)
	);

	// Post Byline Tags
	$wp_customize->add_setting(
		'ifeature_cc_options[single_post_byline_tags]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'single_post_byline_tags',
		array(
			'label'    => __( 'Post Byline Tags', 'ifeature' ),
			'section'  => 'ifeature_cc_template_section',
			'settings' => 'ifeature_cc_options[single_post_byline_tags]',
			'type'     => 'checkbox',
		)
	);

	/*     * ******* End Single Post Options ********** */

	/*     * ******* Start Archive template Options ********** */

	$wp_customize->add_section(
		'ifeature_cc_archive_section',
		array(
			'priority'       => 10,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Archive', 'ifeature' ),
			'panel'          => 'template_id',
		)
	);

	if ( count( $sidebar_choices ) > 1 ) {
		$wp_customize->add_setting(
			'ifeature_cc_options[archive_sidebar_options]',
			array(
				'default'           => 'right_sidebar',
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);

		$wp_customize->add_control(
			new Ifeature_skin_selector(
				$wp_customize,
				'archive_sidebar_options',
				array(
					'label'    => __( 'Sidebar Options', 'ifeature' ),
					'section'  => 'ifeature_cc_archive_section',
					'settings' => 'ifeature_cc_options[archive_sidebar_options]',
					'choices'  => $sidebar_choices,
				)
			)
		);
	}

	// Post Format Icons
	$wp_customize->add_setting(
		'ifeature_cc_options[archive_format_icons]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'archive_format_icons',
		array(
			'label'    => __( 'Post Format Icons', 'ifeature' ),
			'section'  => 'ifeature_cc_archive_section',
			'settings' => 'ifeature_cc_options[archive_format_icons]',
			'type'     => 'checkbox',
		)
	);

	// Post Excerpts
	$wp_customize->add_setting(
		'ifeature_cc_options[archive_post_excerpts]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'archive_post_excerpts',
		array(
			'label'    => __( 'Post Excerpts', 'ifeature' ),
			'section'  => 'ifeature_cc_archive_section',
			'settings' => 'ifeature_cc_options[archive_post_excerpts]',
			'type'     => 'checkbox',
		)
	);

	// Disable Featured Images
	$wp_customize->add_setting(
		'ifeature_cc_options[archive_featured_images]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'archive_featured_images',
		array(
			'label'    => __( 'Featured Images', 'ifeature' ),
			'section'  => 'ifeature_cc_archive_section',
			'settings' => 'ifeature_cc_options[archive_featured_images]',
			'type'     => 'checkbox',
		)
	);

	// Disable Post Byline Author
	$wp_customize->add_setting(
		'ifeature_cc_options[archive_post_byline_author]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'archive_post_byline_author',
		array(
			'label'    => __( 'Post Byline Author', 'ifeature' ),
			'section'  => 'ifeature_cc_archive_section',
			'settings' => 'ifeature_cc_options[archive_post_byline_author]',
			'type'     => 'checkbox',
		)
	);

	// Disable Post Byline Categories
	$wp_customize->add_setting(
		'ifeature_cc_options[archive_post_byline_categories]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'archive_post_byline_categories',
		array(
			'label'    => __( 'Post Byline Categories', 'ifeature' ),
			'section'  => 'ifeature_cc_archive_section',
			'settings' => 'ifeature_cc_options[archive_post_byline_categories]',
			'type'     => 'checkbox',
		)
	);

	// Post Byline Date
	$wp_customize->add_setting(
		'ifeature_cc_options[archive_post_byline_date]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'rchive_post_byline_date',
		array(
			'label'    => __( 'Post Byline Date', 'ifeature' ),
			'section'  => 'ifeature_cc_archive_section',
			'settings' => 'ifeature_cc_options[archive_post_byline_date]',
			'type'     => 'checkbox',
		)
	);

	// Post Byline Comments
	$wp_customize->add_setting(
		'ifeature_cc_options[archive_post_byline_comments]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'archive_post_byline_comments',
		array(
			'label'    => __( 'Post Byline Comments', 'ifeature' ),
			'section'  => 'ifeature_cc_archive_section',
			'settings' => 'ifeature_cc_options[archive_post_byline_comments]',
			'type'     => 'checkbox',
		)
	);

	// Post Byline Tags
	$wp_customize->add_setting(
		'ifeature_cc_options[archive_post_byline_tags]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'archive_post_byline_tags',
		array(
			'label'    => __( 'Post Byline Tags', 'ifeature' ),
			'section'  => 'ifeature_cc_archive_section',
			'settings' => 'ifeature_cc_options[archive_post_byline_tags]',
			'type'     => 'checkbox',
		)
	);

	/*     * ******* End Archive template Options ********** */

	/*     * ******* Start Search template Options ********** */
	$wp_customize->add_section(
		'ifeature_cc_search_section',
		array(
			'priority'       => 10,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Search', 'ifeature' ),
			'panel'          => 'template_id',
		)
	);

	if ( count( $sidebar_choices ) > 1 ) {
		$wp_customize->add_setting(
			'ifeature_cc_options[search_sidebar_options]',
			array(
				'default'           => 'right_sidebar',
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);

		$wp_customize->add_control(
			new Ifeature_skin_selector(
				$wp_customize,
				'search_sidebar_options',
				array(
					'label'    => __( 'Sidebar Options', 'ifeature' ),
					'section'  => 'ifeature_cc_search_section',
					'settings' => 'ifeature_cc_options[search_sidebar_options]',
					'choices'  => $sidebar_choices,
				)
			)
		);
	}

	// Post Excerpts
	$wp_customize->add_setting(
		'ifeature_cc_options[search_post_excerpts]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'search_post_excerpts',
		array(
			'label'    => __( 'Post Excerpts', 'ifeature' ),
			'section'  => 'ifeature_cc_search_section',
			'default'  => 55,
			'settings' => 'ifeature_cc_options[search_post_excerpts]',
			'type'     => 'checkbox',
		)
	);

	// Post Excerpts Read More Text
	$wp_customize->add_setting(
		'ifeature_cc_options[search_post_read_more]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);
	$wp_customize->add_control(
		'search_post_read_more',
		array(
			'label'    => __( 'Read More Text', 'ifeature' ),
			'section'  => 'ifeature_cc_search_section',
			'default'  => __( 'Read More...', 'ifeature' ),
			'settings' => 'ifeature_cc_options[search_post_read_more]',
			'type'     => 'text',
		)
	);

	// Post Excerpts Length
	$wp_customize->add_setting(
		'ifeature_cc_options[search_post_excerpt_length]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);
	$wp_customize->add_control(
		'search_post_excerpt_length',
		array(
			'label'    => __( 'Excerpt Length', 'ifeature' ),
			'section'  => 'ifeature_cc_search_section',
			'settings' => 'ifeature_cc_options[search_post_excerpt_length]',
			'type'     => 'text',
		)
	);

	/*     * ******* End Search template Options ********** */

	/*     * ******* Start 404 template Options ********** */

	$wp_customize->add_section(
		'ifeature_cc_error_section',
		array(
			'priority'       => 10,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( '404', 'ifeature' ),
			'panel'          => 'template_id',
		)
	);

	if ( count( $sidebar_choices ) > 1 ) {
		$wp_customize->add_setting(
			'ifeature_cc_options[error_sidebar_options]',
			array(
				'default'           => 'right_sidebar',
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);

		$wp_customize->add_control(
			new Ifeature_skin_selector(
				$wp_customize,
				'error_sidebar_options',
				array(
					'label'    => __( 'Sidebar Options', 'ifeature' ),
					'section'  => 'ifeature_cc_error_section',
					'settings' => 'ifeature_cc_options[error_sidebar_options]',
					'choices'  => $sidebar_choices,
				)
			)
		);
	}

	// Custom 404 Title
	$wp_customize->add_setting(
		'ifeature_cc_options[error_custom_title]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);
	$wp_customize->add_control(
		'error_custom_title',
		array(
			'label'    => __( 'Custom 404 Title', 'ifeature' ),
			'section'  => 'ifeature_cc_error_section',
			'settings' => 'ifeature_cc_options[error_custom_title]',
			'type'     => 'text',
		)
	);

	// Custom 404 Content
	$wp_customize->add_setting(
		'ifeature_cc_options[error_custom_content]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_textarea',
		)
	);
	$wp_customize->add_control(
		'error_custom_content',
		array(
			'label'    => __( 'Custom 404 Content', 'ifeature' ),
			'section'  => 'ifeature_cc_error_section',
			'settings' => 'ifeature_cc_options[error_custom_content]',
			'type'     => 'textarea',
		)
	);

	/*     * ******* End 404 template Options ********** */

	/*
	 --------------------------------------------------------------
	  // FOOTER SECTION
	  -------------------------------------------------------------- */

	$wp_customize->add_section(
		'ifeature_cc_footer_section',
		array(
			'title'    => __( 'Footer', 'ifeature' ),
			'priority' => 60,
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[footer_show_toggle]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'footer_show_toggle',
		array(
			'label'    => __( 'Footer Widgets', 'ifeature' ),
			'section'  => 'ifeature_cc_footer_section',
			'settings' => 'ifeature_cc_options[footer_show_toggle]',
			'type'     => 'checkbox',
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[footer_copyright_text]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);
	$wp_customize->add_control(
		'footer_copyright_text',
		array(
			'label'    => __( 'Footer Copyright Text', 'ifeature' ),
			'section'  => 'ifeature_cc_footer_section',
			'settings' => 'ifeature_cc_options[footer_copyright_text]',
			'type'     => 'text',
		)
	);

	/*
	 --------------------------------------------------------------
	  // LAYOUT SECTION
	  -------------------------------------------------------------- */
	$wp_customize->add_section(
		'ifeature_cc_layout_section',
		array(
			'title'    => __( 'Layout', 'ifeature' ),
			'priority' => 30,
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[responsive_design]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'responsive_design',
		array(
			'label'    => __( 'Responsive Design', 'ifeature' ),
			'section'  => 'ifeature_cc_layout_section',
			'settings' => 'ifeature_cc_options[responsive_design]',
			'type'     => 'checkbox',
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[responsive_videos]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'responsive_videos',
		array(
			'label'    => __( 'Responsive Videos', 'ifeature' ),
			'section'  => 'ifeature_cc_layout_section',
			'settings' => 'ifeature_cc_options[responsive_videos]',
			'type'     => 'checkbox',
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[gallery_lightbox]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'gallery_lightbox',
		array(
			'label'    => __( 'Gallery Lightbox', 'ifeature' ),
			'section'  => 'ifeature_cc_layout_section',
			'settings' => 'ifeature_cc_options[gallery_lightbox]',
			'type'     => 'checkbox',
		)
	);

	$wp_customize->add_setting(
		'ifeature_cc_options[wide_sidebar]',
		array(
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_sanitize_checkbox',
		)
	);
	$wp_customize->add_control(
		'wide_sidebar',
		array(
			'label'       => __( 'Wide Sidebar', 'ifeature' ),
			'section'     => 'ifeature_cc_layout_section',
			'description' => __( 'Only works on layouts with 1 sidebar', 'ifeature' ),
			'settings'    => 'ifeature_cc_options[wide_sidebar]',
			'type'        => 'checkbox',
		)
	);

	// website width
	$wp_customize->add_setting(
		'ifeature_cc_options[max_width]',
		array(
			'default'           => apply_filters( 'ifeature_cc_max_width_default', '1140' ),
			'type'              => 'option',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'max_width',
		array(
			'label'    => __( 'Max Width', 'ifeature' ),
			'section'  => 'ifeature_cc_layout_section',
			'type'     => 'text',
			'settings' => 'ifeature_cc_options[max_width]',
		)
	);

	// Design

	$wp_customize->add_section(
		'ifeature_cc_design_section',
		array(
			'title'    => __( 'Design', 'ifeature' ),
			'priority' => 35,
		)
	);

	// theme skin
	// First check that there is more than one skin to show, otherwise hide the options as requested by WP
	$choices = apply_filters( 'ifeature_cc_skin_color', array( 'default' => get_template_directory_uri() . '/inc/css/skins/images/default.png' ) );
	if ( count( $choices ) > 1 ) {
		$wp_customize->add_setting(
			'ifeature_cc_options[ifeature_cc_skin_color]',
			array(
				'default'           => get_template_directory_uri() . '/inc/css/skins/images/default.png',
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_text_sanitization',
			)
		);

		$wp_customize->add_control(
			new Ifeature_skin_selector(
				$wp_customize,
				'skin_color',
				array(
					'label'    => __( 'Skin Color', 'ifeature' ),
					'section'  => 'ifeature_cc_design_section',
					'settings' => 'ifeature_cc_options[ifeature_cc_skin_color]',
					'choices'  => $choices,
				)
			)
		);
	}

	// text color
	$wp_customize->add_setting(
		'ifeature_cc_options[text_colorpicker]',
		array(
			'default'           => '',
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'text_colorpicker',
			array(
				'label'    => __( 'Text Color', 'ifeature' ),
				'section'  => 'ifeature_cc_design_section',
				'settings' => 'ifeature_cc_options[text_colorpicker]',
			)
		)
	);

	// link color
	$wp_customize->add_setting(
		'ifeature_cc_options[link_colorpicker]',
		array(
			'default'           => '',
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'link_colorpicker',
			array(
				'label'    => __( 'Link Color', 'ifeature' ),
				'section'  => 'ifeature_cc_design_section',
				'settings' => 'ifeature_cc_options[link_colorpicker]',
			)
		)
	);

	// link hover color
	$wp_customize->add_setting(
		'ifeature_cc_options[link_hover_colorpicker]',
		array(
			'default'           => '',
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'link_hover_colorpicker',
			array(
				'label'    => __( 'Link Hover Color', 'ifeature' ),
				'section'  => 'ifeature_cc_design_section',
				'settings' => 'ifeature_cc_options[link_hover_colorpicker]',
			)
		)
	);

	// Custom CSS
	if ( 'pro' == ifeature_cc_theme_check() ) {
		$wp_customize->add_setting(
			'ifeature_cc_options[custom_css]',
			array(
				'default'           => '',
				'type'              => 'option',
				'sanitize_callback' => 'ifeature_cc_sanitize_textarea',
			)
		);

		// Content area
		$wp_customize->add_control(
			new Ifeature_Form(
				$wp_customize,
				'custom_css',
				array(
					'section'  => 'ifeature_cc_design_section',
					'settings' => 'ifeature_cc_options[custom_css]',
					'type'     => 'textarea',
				)
			)
		);
	}

	// new typography section
	$wp_customize->add_section(
		'ifeature_cc_typography_section',
		array(
			'title'    => __( 'Typography', 'ifeature' ),
			'priority' => 40,
		)
	);

	// typography sizes
	$wp_customize->add_setting(
		'ifeature_cc_options[typography_options][size]',
		array(
			'default'           => '14px',
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		new Ifeature_Typography_Size(
			$wp_customize,
			'typography_size',
			array(
				'label'    => __( 'Typography Size', 'ifeature' ),
				'section'  => 'ifeature_cc_typography_section',
				'type'     => 'select',
				'settings' => 'ifeature_cc_options[typography_options][size]',
				'choices'  => apply_filters( 'ifeature_cc_typography_sizes', '' ),
			)
		)
	);

	// typography style
	$wp_customize->add_setting(
		'ifeature_cc_options[typography_options][style]',
		array(
			'default'           => 'normal',
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		'typography_style',
		array(
			'label'    => __( 'Typography Style', 'ifeature' ),
			'section'  => 'ifeature_cc_typography_section',
			'type'     => 'select',
			'settings' => 'ifeature_cc_options[typography_options][style]',
			'choices'  => apply_filters( 'ifeature_cc_typography_styles', '' ),
		)
	);

	// typography face
	/* Default font faces */
	$faces = array(
		'Arial, Helvetica, sans-serif'                     => 'Arial',
		'Arial Black, Gadget, sans-serif'                  => 'Arial Black',
		'Comic Sans MS, cursive'                           => 'Comic Sans MS',
		'Courier New, monospace'                           => 'Courier New',
		'Georgia, serif'                                   => 'Georgia',
		'"HelveticaNeue-Light", "Helvetica Neue Light",
		"Helvetica Neue",Helvetica, Arial, "Lucida Grande",
		sans-serif'                                        => 'Helvetica Neue',
		'Impact, Charcoal, sans-serif'                     => 'Impact',
		'Lucida Console, Monaco, monospace'                => 'Lucida Console',
		'Lucida Sans Unicode, Lucida Grande, sans-serif'   => 'Lucida Sans Unicode',
		'"Open Sans", sans-serif'                          => 'Open Sans',
		'Palatino Linotype, Book Antiqua, Palatino, serif' => 'Palatino Linotype',
		'Tahoma, Geneva, sans-serif'                       => 'Tahoma',
		'Times New Roman, Times, serif'                    => 'Times New Roman',
		'Trebuchet MS, sans-serif'                         => 'Trebuchet MS',
		'Verdana, Geneva, sans-serif'                      => 'Verdana',
		'Symbol'                                           => 'Symbol',
		'Webdings'                                         => 'Webdings',
		'Wingdings, Zapf Dingbats'                         => 'Wingdings',
		'MS Sans Serif, Geneva, sans-serif'                => 'MS Sans Serif',
		'MS Serif, New York, serif'                        => 'MS Serif',
		'Google Fonts'                                     => 'Google Fonts',
	);
	// Font family for text
	$wp_customize->add_setting(
		'ifeature_cc_options[typography_options][face]',
		array(
			'default'           => 'Arial',
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		'typography_face',
		array(
			'label'    => __( 'Typography Face', 'ifeature' ),
			'section'  => 'ifeature_cc_typography_section',
			'type'     => 'select',
			'settings' => 'ifeature_cc_options[typography_options][face]',
			'choices'  => apply_filters( 'ifeature_cc_typography_faces', $faces ),
		)
	);

	// Google Font family for text
	$wp_customize->add_setting(
		'ifeature_cc_options[google_font_field]',
		array(
			'default'           => 'Arial',
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		'google_font_field',
		array(
			'label'    => __( 'Enter Google font', 'ifeature' ),
			'section'  => 'ifeature_cc_typography_section',
			'type'     => 'text',
			'settings' => 'ifeature_cc_options[google_font_field]',
		)
	);

	// Font family for headings
	$wp_customize->add_setting(
		'ifeature_cc_options[font_family_headings][face]',
		array(
			'default'           => 'Arial',
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		'font_family_headings',
		array(
			'label'    => __( 'Font Family for headings', 'ifeature' ),
			'section'  => 'ifeature_cc_typography_section',
			'type'     => 'select',
			'settings' => 'ifeature_cc_options[font_family_headings][face]',
			'choices'  => apply_filters( 'ifeature_cc_typography_faces', $faces ),
		)
	);

	// Google Font family for headings
	$wp_customize->add_setting(
		'ifeature_cc_options[google_font_headings]',
		array(
			'default'           => 'Arial',
			'type'              => 'option',
			'sanitize_callback' => 'ifeature_cc_text_sanitization',
		)
	);

	$wp_customize->add_control(
		'google_font_headings',
		array(
			'label'    => __( 'Google font for headings', 'ifeature' ),
			'section'  => 'ifeature_cc_typography_section',
			'type'     => 'text',
			'settings' => 'ifeature_cc_options[google_font_headings]',
		)
	);

	// background image
	$wp_customize->add_setting(
		'ifeature_cc_background',
		array(
			'default'           => 'none',
			'type'              => 'theme_mod',
			'sanitize_callback' => 'ifeature_cc_file_sanitization',
		)
	);

	$wp_customize->add_control(
		new Ifeature_Background_Image(
			$wp_customize,
			'ifeature_cc_background',
			array(
				'label'    => 'CyberChimps ' . __( 'Background Image', 'ifeature' ),
				'section'  => 'background_image',
				'settings' => 'ifeature_cc_background',
				'choices'  => apply_filters( 'ifeature_cc_background_image', '' ),
			)
		)
	);
}

/**
 * Text field sanitization
 *
 * @param $text
 *
 * @return string
 */
function ifeature_cc_text_sanitization( $text ) {
	return sanitize_text_field( $text );
}

/**
 * File sanitization
 *
 * @param $text
 *
 * @return string
 */
function ifeature_cc_file_sanitization( $name ) {
	return sanitize_file_name( $name );
}

/**
 * Multiple checkbox validation
 *
 * @param $values
 * @return string:
 */
function ifeature_cc_sanitize_multiple_checkboxes( $values ) {

	$multi_values = ! is_array( $values ) ? explode( ',', $values ) : $values;

	return ! empty( $multi_values ) ? array_map( 'sanitize_text_field', $multi_values ) : array();
}

/**
 * Adds custom controls.
 *
 * @param object $wp_customize WordPress customizer.
 *
 * @since 1.0.0
 */
function ifeature_cc_custom_controls( $wp_customize ) {

	// Path.
	$dir = get_template_directory() . '/cyberchimps/options/controls/';

	// Load customize control classes.
	require_once $dir . 'sortable/class-cyberchimps-customizer-sortable-control.php';

	// Register JS control types.
	$wp_customize->register_control_type( 'Ifeature_Customizer_Sortable_Control' );

	$wp_customize->add_setting(
		'blog_section_order',
		array(
			'default'           => array( 'blog_post_page' ),
			'sanitize_callback' => 'ifeature_cc_sanitize_multi_choices',
			'transport'         => 'refresh',
		)
	);
	$wp_customize->add_control(
		new Ifeature_Customizer_Sortable_Control(
			$wp_customize,
			'blog_section_order',
			array(
				'label'    => esc_html__( 'Drag & Drop Blog Elements', 'ifeature' ),
				'section'  => 'ifeature_cc_layout_section',
				'settings' => 'blog_section_order',
				'priority' => 10,
				'choices'  => apply_filters(
					'ifeature_cc_elements_draganddrop_options',
					array(
						'boxes_lite'     => __( 'Boxes', 'ifeature' ),
						'portfolio_lite' => __( 'Portfolio Lite', 'ifeature' ),
						'blog_post_page' => __( 'Post Page', 'ifeature' ),
						'slider_lite'    => __( 'Slider Lite', 'ifeature' ),
					)
				),
			)
		)
	);
	$wp_customize->add_setting(
		'header_section_order',
		array(
			'default'           => array( 'ifeature_cc_header_content' ),
			'sanitize_callback' => 'ifeature_cc_sanitize_multi_choices',
			'transport'         => 'refresh',
		)
	);
	$wp_customize->add_control(
		new Ifeature_Customizer_Sortable_Control(
			$wp_customize,
			'header_section_order',
			array(
				'label'    => esc_html__( 'Drag & Drop Header Elements', 'ifeature' ),
				'section'  => 'ifeature_cc_layout_section',
				'settings' => 'header_section_order',
				'priority' => 10,
				'choices'  => apply_filters(
					'header_drag_and_drop_options',
					array(
						'ifeature_cc_header_content' => __( 'Logo + Icons', 'ifeature' ),
						'ifeature_cc_logo_search'    => __( 'Logo + Search', 'ifeature' ),
						'ifeature_cc_logo'           => __( 'Logo', 'ifeature' ),
					)
				),
			)
		)
	);
}
add_action( 'customize_register', 'ifeature_cc_custom_controls' );

/**
 * Select choices sanitization callback
 *
 * @param  object $input    arguments.
 * @param  object $setting    arguments.
 * @since 1.2.1
 */
function ifeature_cc_sanitize_multi_choices( $input, $setting ) {
	// Get list of choices from the control associated with the setting.
	$choices    = $setting->manager->get_control( $setting->id )->choices;
	$input_keys = $input;

	foreach ( $input_keys as $key => $value ) {
		if ( ! array_key_exists( $value, $choices ) ) {
			unset( $input[ $key ] );
		}
	}
	// If the input is a valid key, return it;
	// otherwise, return the default.
	return ( is_array( $input ) ? $input : $setting->default );
}
